@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+from rest_framework.compat import six
+from rest_framework.exceptions import ParseError
 from rest_framework.parsers import JSONParser
 from django.conf import settings
 import re
@@ -33,4 +35,4 @@ class CamelCaseJSONParser(JSONParser):
             data = stream.read().decode(encoding)
             return underscoreize(json.loads(data))
         except ValueError as exc:
-            raise ParseError('JSON parse error - %s' % six.text_type(exc))
\ No newline at end of file
+            raise ParseError('JSON parse error - %s' % six.text_type(exc))
