@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
-from rest_framework.renderers import JSONRenderer
 import re
+from collections import OrderedDict
+from rest_framework.renderers import JSONRenderer
 
 def underscoreToCamel(match):
     return match.group()[0] + match.group()[2].upper()
 
 def camelize(data):
     if isinstance(data, dict):
-        new_dict = {}
+        new_dict = OrderedDict()
         for key, value in data.items():
             new_key = re.sub(r"[a-z]_[a-z]", underscoreToCamel, key)
             new_dict[new_key] = camelize(value)
